@@ -35,6 +35,8 @@ char lin_our_user[ALLOC_USER];
 char lin_our_host[ALLOC_HOST];
 char lin_prefix[ALLOC_MINIBUFFER];
 char lin_our_server[ALLOC_HOST];
+char *lin_input = NULL;
+size_t lin_input_len = 0;
 TF lin_active = FALSE;
 TF lin_registering = FALSE;
 unsigned long lin_our_addr;
@@ -770,6 +772,8 @@ void OnNick(const char *str)
   int c = strlen(lin_our_nick);
   char nick[ALLOC_NICK];
   const char *temp = str;
+  if (*temp==':')
+    temp++;
   Util_SepTo(nick, ALLOC_NICK, &temp, 32);
   if (lin_prefix[c]=='!' &&
       strncasecmp(lin_prefix, lin_our_nick, c)==0) {
@@ -871,8 +875,6 @@ const struct strtofunc_map EVENT_LIST[] = {
 void StartMessage()
 {
   fd_set reads;
-  char *input = NULL;
-  size_t len = 0;
   const char *cmd, *data;
   int c;
   PDCC dcc;
@@ -889,12 +891,12 @@ void StartMessage()
 	if (dcc->listen)
 	  AcceptDCC(dcc);
 	else {
-	  int r = fdgetline(&input, &len, dcc->sock);
+	  int r = fdgetline(&lin_input, &lin_input_len, dcc->sock);
 	  if (r<1)
 	    OnDCCChatClose(dcc);
 	  else {
-	    *strchr(input, '\n')=0;
-	    OnDCCChatMSG(dcc, input);
+	    *strchr(lin_input, '\n')=0;
+	    OnDCCChatMSG(dcc, lin_input);
 	  }
 	}
       }
@@ -902,23 +904,23 @@ void StartMessage()
 
     if (FD_ISSET(lin_fd, &reads)) {
       char *ptr;
-      if (fdgetline(&input, &len, lin_fd)<0) {
+      if (fdgetline(&lin_input, &lin_input_len, lin_fd)<0) {
 	fprintf(stderr, "Error reading socket: %m\n");
 	exit (255);
       }
-      *(strchr(input, '\n'))=0;
-      ptr = strchr(input, '\r');
+      *(strchr(lin_input, '\n'))=0;
+      ptr = strchr(lin_input, '\r');
       if (ptr!=NULL)
 	*ptr = 0;
 #ifdef DEBUG
-      fprintf(stderr, "DEBUG - Received from server: %s\n", input);
+      fprintf(stderr, "DEBUG - Received from server: %s\n", lin_input);
 #endif
-      if (input[0]==':') {
-	ptr = input + 1;
+      if (lin_input[0]==':') {
+	ptr = lin_input + 1;
 	Util_SepTo(lin_prefix, ALLOC_MINIBUFFER, (const char **)&ptr, 32);
       } else {
 	*lin_prefix=0;
-	ptr = input;
+	ptr = lin_input;
       }
       if (ptr[0]>='0'&&ptr[0]<='9')
 	OnNumeric(ptr);
@@ -1021,6 +1023,11 @@ void LowIrcCleanup()
 #ifdef DEBUG
   fputs("DEBUG - LowIrcCleanup called\n", stderr);
 #endif
+  if (lin_input!=NULL) {
+    free(lin_input);
+    lin_input=NULL;
+    lin_input_len=0;
+  }
   if (lin_read_fds!=NULL) {
     free (lin_read_fds);
     lin_read_fds = NULL;
